import QtQuick 1.1
import com.nokia.meego 1.0


PageStackWindow {
    id: appWindow

    initialPage: mainPage
    showStatusBar: false
    showToolBar: false

    signal initAudio
    signal playSound

    property bool showAboutInfo: false
    property bool windowActivated: Qt.application.active? true : false

    // Handle paused mode when game is minimized
    onWindowActivatedChanged: {

            if(appWindow.windowActivated)
                playLoader.source = Qt.resolvedUrl("playPage.qml")
            else if(!showAboutInfo)
                pausedLoader.source = Qt.resolvedUrl("pausedScreen.qml")

    }

    // Show the audio loading progress in the splash screen
    function setAudioProgress(loaded, total) {

        mainPage.eventText = "Loading sounds: " + loaded + "/" + total + "...";

        mainPage.progressValue = loaded
        mainPage.progressTotal = total

        // If all sounds were loaded...
        if(loaded === total) {

            // Toolbar must be shown only if it is not minimized, otherwise it will pause...
            if(appWindow.windowActivated)
                appWindow.showToolBar = true
            mainPage.eventText = "ENJOY!!!"
            splashLoader.item.opacity = 0
            timerB.start()                      // Just a timer to wait for the fadeout effect
        }
    }

    // This is my toolBar element :)
    ToolBarLayout {
        id: toolBar
        visible: false

        ToolIcon {
            id: menuIcon
            visible: true
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (myMenu.status === DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
        ToolIcon {
            id: backIcon
            visible: false
            platformIconId: "toolbar-back"
            anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: {
                playLoader.source = Qt.resolvedUrl("playPage.qml")
            }

        }
    }

    // A simple menu to access About dialog and a Quit element
    Menu {
        id: myMenu
        visualParent: pageStack

        MenuLayout {

            MenuItem {
                text: qsTr("About")
                onClicked: {
                    showAboutInfo = true            // If this is true, pausedScreen will show the about information
                    pausedLoader.source = Qt.resolvedUrl("pausedScreen.qml")
                }
            }

            MenuItem {
                text: qsTr("Quit")
                onClicked: Qt.quit()
            }
        }
    }

    Page {
        id: mainPage
        tools: toolBar
        orientationLock: PageOrientation.LockPortrait

        property bool gameEnable: false
        property int progressValue: 0
        property int progressTotal: 0
        property string eventText: "Starting game..."

        // Loader for main game
        Loader {
            id: playLoader
            width: parent.width
            height: parent.height

            z: 0

            onLoaded: {
                // I need a toolbar only after the splash screen has faded away
                if(mainPage.gameEnable)
                    appWindow.showToolBar = true
                backIcon.visible = false;
                menuIcon.visible = true;
                pausedLoader.sourceComponent = undefined
                showAboutInfo = false
            }
        }

        Loader {
            id: pausedLoader
            width: parent.width
            height: parent.height

            z: 25

            onLoaded: {
                if(!appWindow.showAboutInfo)
                    appWindow.showToolBar = false
                else {
                    backIcon.visible = true;
                    menuIcon.visible = false;
                }

                playLoader.sourceComponent = undefined
            }
        }

        Loader {
            id: splashLoader
            width: parent.width
            height: parent.height
            source: Qt.resolvedUrl("splashScreen.qml")

            z: 50

            onLoaded: timerA.start()
        }

        Timer {
            id: timerA
            interval: 1000
            running: false
            repeat: false

            onTriggered: {
                initAudio()
                playLoader.source = Qt.resolvedUrl("playPage.qml")
            }
        }

        Timer {
            id: timerB
            interval: 1500
            running: false
            repeat: false

            onTriggered: {
                splashLoader.sourceComponent = undefined
                mainPage.gameEnable = true
            }
        }

    }

}
