import QtQuick 1.1
import com.nokia.meego 1.0
import Qt.labs.particles 1.0
import QtMobility.feedback 1.1
import QtMultimediaKit 1.1


Rectangle {
    id: container
    color: "black"
    anchors.fill: parent

    Behavior on opacity { NumberAnimation { duration: 1500 } }

    property int screenWidth: parent.width
    property int screenHeight: parent.height
    property int gridColumns: 3
    property int gridRows: 5
    property int gridElementsCount: gridColumns*gridRows
    property int animDuration: 500

    property int toddlerLockState: 0
    property int lastMouseX: 0
    property int lastMouseY: 0
    property int lastRectPressed: 0

    Grid {
        id: grid
        columns: gridColumns
        rows: gridRows

        Repeater {
            id: rectRepeater
            model: gridElementsCount

            Rectangle {
                property real hue: Math.random()
                property real lum: .3
                property real sclXY: 1
                property int myPartRate: -1
                property int myPartCount: -1

                Text {
                    id: rectText
                    anchors.centerIn: parent
                    color: "white"
                    visible: false
                    smooth: true
                    font.bold: true
                    font.pointSize: 12

                    text: "TAP!"
                }

                onMyPartCountChanged: {
                    partRCircle.count = myPartCount
                    partGCircle.count = myPartCount
                    partBCircle.count = myPartCount
                }

                onMyPartRateChanged: {
                    partRCircle.emissionRate = myPartRate
                    partGCircle.emissionRate = myPartRate
                    partBCircle.emissionRate = myPartRate
                }

                id: rect
                width: screenWidth/gridColumns
                height: screenHeight/gridRows
                color: Qt.hsla(hue, 1, lum, 1)
                rotation: 0
                border.width: width/10
                border.color: Qt.hsla((hue > .5) ? hue - .5: hue + .5, 1, lum, 1)
                radius: width/5
                smooth: true

                transform: [
                    Rotation {
                        id: rot
                        origin.x: rect.width/2
                        origin.y: rect.height/2
                        axis.x: 0; axis.y: 0; axis.z: 1
                        angle: 0

                        Behavior on angle {
                            PropertyAnimation {
                                easing.type: Easing.OutExpo
                                duration: animDuration * 5
                            }
                        }
                    },
                    Scale {
                        id: scl
                        origin.x: rect.width/2
                        origin.y: rect.height/2
                        xScale: 1
                        yScale: 1

                        Behavior on xScale {
                            PropertyAnimation {
                                duration: animDuration
                            }
                        }
                        Behavior on yScale {
                            PropertyAnimation {
                                duration: animDuration
                            }
                        }
                    }

                ]

                Behavior on hue {
                    PropertyAnimation {
                        duration: animDuration
                    }
                }

                Behavior on lum {
                    PropertyAnimation {
                        easing.overshoot: 10
                        easing.type: Easing.InOutBack
                        duration: animDuration
                    }
                }

                MouseArea {
                    id: mouseArea
                    anchors.fill: parent
                    enabled: mainPage.gameEnable

                    onPressed: {
                        rectRepeater.itemAt(lastRectPressed).myPartRate = 0
                        rectRepeater.itemAt(lastRectPressed).myPartCount = 0
                        rectRepeater.itemAt(lastRectPressed).lum = .3

                        lastRectPressed = index
                        timer.restart();

                        if(index === 0) {
                            toddlerLockState = 1
                            circle.x = rectRepeater.itemAt(gridColumns - 1).x
                            circle.y = rectRepeater.itemAt(gridColumns - 1).y
                            seqAnim.restart();
                        }
                        else if((index === (gridColumns - 1)) && (toddlerLockState == 1) && seqAnim.running) {
                            toddlerLockState = 2
                            circle.x = rectRepeater.itemAt(gridRows * gridColumns - 1).x
                            circle.y = rectRepeater.itemAt(gridRows * gridColumns - 1).y
                            seqAnim.restart();
                        }
                        else if((index === (gridRows * gridColumns - 1)) && (toddlerLockState == 2) && seqAnim.running) {
                            toddlerLockState = 3
                            circle.x = rectRepeater.itemAt((gridRows - 1) * gridColumns).x
                            circle.y = rectRepeater.itemAt((gridRows - 1) * gridColumns).y
                            seqAnim.restart();
                        }
                        else if((index === ((gridRows - 1) * gridColumns)) && (toddlerLockState == 3) && seqAnim.running)
                            toddlerLockState = 4
                        else {
                            toddlerLockState = 0
                            seqAnim.stop();
                        }

                        if(toddlerLockState == 4) {
                            toddlerLockState = 0
                            appWindow.showToolBar = !appWindow.showToolBar
                            screen.allowSwipe = !screen.allowSwipe
                            seqAnim.stop();
                        }

                        rot.angle += (720 * (Math.random() + 1)) * (Math.random() > .5 ? 1 : -1)
                        sclXY = Math.random() + .5
                        scl.xScale = sclXY
                        scl.yScale = sclXY
                        myPartRate = 50
                        myPartCount = 500
                        hue = Math.random()
                        lum = .5
                        vibration.start()

                        appWindow.playSound()           // Emit signal to audio thread
                    }

                }

                HapticsEffect {
                    id: vibration
                    attackIntensity: 0.0
                    attackTime: 150
                    intensity: 1.0
                    duration: 200
                    fadeTime: 150
                    fadeIntensity: 0.0
                }

                Particles {
                    id: partRCircle
                    y: rect.height/2
                    x: rect.width/2
                    width: 1
                    height: 1
                    source: "qrc:///images/red_circle.png"
                    lifeSpan: 2000
                    emissionRate: -1
                    count: -1
                    angle: 0
                    angleDeviation: 360
                    velocity: 150
                    velocityDeviation: 130
                }

                Particles {
                    id: partGCircle
                    y: rect.height/2
                    x: rect.width/2
                    width: 1
                    height: 1
                    source: "qrc:///images/green_circle.png"
                    lifeSpan: 2000
                    emissionRate: -1
                    count: -1
                    angle: 0
                    angleDeviation: 360
                    velocity: 150
                    velocityDeviation: 130
                }

                Particles {
                    id: partBCircle
                    y: rect.height/2
                    x: rect.width/2
                    width: 1
                    height: 1
                    source: "qrc:///images/blue_circle.png"
                    lifeSpan: 2000
                    emissionRate: -1
                    count: -1
                    angle: 0
                    angleDeviation: 360
                    velocity: 150
                    velocityDeviation: 130
                }

            }
        }

        Rectangle {
            id: circle

            width: screenWidth/gridColumns
            height: screenHeight/gridRows
            radius: width/2
            color: "White"
            border.width: width/20
            border.color: "LightGray"
            smooth: true

            opacity: 0
            scale: .7

            SequentialAnimation {
                id: seqAnim
                running: false
                loops: Animation.Infinite
                alwaysRunToEnd: true

                NumberAnimation { target: circle; property: "opacity"; from: 0; to: .5; duration: 100 }
                NumberAnimation { target: circle; property: "opacity"; from: .5; to: 0; duration: 500 }
            }

            Text {
                anchors.fill: parent
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap

                text: "Tap for Baby lock!"
                font.bold: true
                font.pixelSize: 30
                color: "White"
            }
        }

    }

    Particles {
        id: partStar
        y: container.y
        width: container.width
        height: 1
        source: "qrc:///images/star_1.png"
        lifeSpan: 10000
        emissionRate: 50
        count: 500
        angle: 90
        angleDeviation:30
        velocity: 80
        velocityDeviation: 70
    }

    Timer {
        id: timer
        interval: 5000; running: false; repeat: false
        onTriggered: {
            rectRepeater.itemAt(lastRectPressed).myPartRate = 0
            rectRepeater.itemAt(lastRectPressed).myPartCount = 0
            seqAnim.stop();
        }
    }

}
